@@ -1,4 +1,6 @@
 import warnings
+from typing import Tuple
+
 import numpy as np
 from sklearn.metrics import average_precision_score, roc_curve
 
@@ -12,7 +14,7 @@ def mean_average_precision(correct):
     return np.mean([average_precision_score(c, np.arange(len(c), 0, -1)) if np.any(c) else 0 for c in correct])
 
 
-def tpr_at_tnr(probs, labels, at_tnr):
+def tpr_at_tnr(probs, labels, at_tnr) -> Tuple[float, float]:
     import torch
     if isinstance(probs, torch.Tensor):
         probs = probs.detach().cpu().numpy()
@@ -23,13 +25,13 @@ def tpr_at_tnr(probs, labels, at_tnr):
     labels = labels.flatten()
 
     try:
-        fpr, tpr, _ = roc_curve(labels, probs)
+        fpr, tpr, thresholds = roc_curve(labels, probs)
     except ValueError:
         warnings.warn('Could not calculate roc curve due to a ValueError')
-        return 0
+        return 0, 0
 
     tnr = 1 - fpr   # in decreasing order
     for idx in range(1, len(tnr)):
         if tnr[idx] < at_tnr:
-            return tpr[idx-1]
-    return 0
+            return tpr[idx-1], thresholds[idx-1]
+    return 0, 0
